@@ -4,17 +4,17 @@ from e3nn import o3
 from e3nn.util.jit import compile_mode
 
 
-@compile_mode('script')
+@compile_mode('trace')
 class Norm(torch.nn.Module):
-    r"""Norm operation
+    r"""Norm of each irrep in a direct sum of irreps.
 
     Parameters
     ----------
     irreps_in : `Irreps`
         representation of the input
 
-    normalization : {'component', 'norm'}
-        see `TensorProduct`
+    squared : bool, optional
+        Whether to return the squared norm. ``False`` by default, i.e. the norm itself (sqrt of squared norm) is returned.
 
     Examples
     --------
@@ -24,9 +24,12 @@ class Norm(torch.nn.Module):
     >>> norm(torch.randn(17 * 3)).shape
     torch.Size([17])
     """
+    squared: bool
+
     def __init__(
         self,
         irreps_in,
+        squared: bool = False
     ):
         super().__init__()
 
@@ -48,12 +51,13 @@ class Norm(torch.nn.Module):
 
         self.irreps_in = irreps_in
         self.irreps_out = irreps_out.simplify()
+        self.squared = squared
 
     def __repr__(self):
         return f"{self.__class__.__name__}({self.irreps_in})"
 
     def forward(self, features):
-        """evaluate
+        """Compute norms of irreps in ``features``.
 
         Parameters
         ----------
@@ -65,4 +69,9 @@ class Norm(torch.nn.Module):
         `torch.Tensor`
             tensor of shape ``(..., irreps_out.dim)``
         """
-        return self.tp(features, features).sqrt()
+        out = self.tp(features, features)
+        if self.squared:
+            return out
+        else:
+            # ReLU fixes gradients at zero
+            return out.relu().sqrt()
