@@ -307,7 +307,10 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         if self.irreps_out.dim > 0:
             output_mask = torch.cat([
                 torch.ones(mul * ir.dim)
-                if any(i.i_out == i_out and i.path_weight > 0 for i in self.instructions)
+                if any(
+                    (ins.i_out == i_out) and (ins.path_weight != 0) and (0 not in ins.path_shape)
+                    for ins in self.instructions
+                )
                 else torch.zeros(mul * ir.dim)
                 for i_out, (mul, ir) in enumerate(self.irreps_out)
             ])
@@ -458,7 +461,8 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         offset = sum(prod(ins.path_shape) for ins in self.instructions[:instruction])
         ins = self.instructions[instruction]
         weight = self._get_weights(weight)
-        return weight[offset:offset + prod(ins.path_shape)].view(ins.path_shape)
+        batchshape = weight.shape[:-1]
+        return weight.narrow(-1, offset, prod(ins.path_shape)).view(batchshape + ins.path_shape)
 
     def weight_views(
         self,
@@ -481,11 +485,12 @@ class TensorProduct(CodeGenMixin, torch.nn.Module):
         Otherwise, yields ``weight_view``.
         """
         weight = self._get_weights(weight)
+        batchshape = weight.shape[:-1]
         offset = 0
         for ins_i, ins in enumerate(self.instructions):
             if ins.has_weight:
                 flatsize = prod(ins.path_shape)
-                this_weight = weight[offset:offset + flatsize].view(ins.path_shape)
+                this_weight = weight.narrow(-1, offset, flatsize).view(batchshape + ins.path_shape)
                 offset += flatsize
                 if yield_instruction:
                     yield ins_i, ins, this_weight
@@ -723,9 +728,9 @@ class FullyConnectedTensorProduct(TensorProduct):
         irreps_out,
         **kwargs
     ):
-        irreps_in1 = o3.Irreps(irreps_in1).simplify()
-        irreps_in2 = o3.Irreps(irreps_in2).simplify()
-        irreps_out = o3.Irreps(irreps_out).simplify()
+        irreps_in1 = o3.Irreps(irreps_in1)
+        irreps_in2 = o3.Irreps(irreps_in2)
+        irreps_out = o3.Irreps(irreps_out)
 
         instr = [
             (i_1, i_2, i_out, 'uvw', True, 1.0)
@@ -816,7 +821,6 @@ class ElementwiseTensorProduct(TensorProduct):
                     (i, i, i_out, 'uuu', False)
                 ]
 
-        kwargs['internal_weights'] = False
         super().__init__(irreps_in1, irreps_in2, out, instr, **kwargs)
 
 
@@ -880,5 +884,4 @@ class FullTensorProduct(TensorProduct):
             for i_1, i_2, i_out, mode, train in instr
         ]
 
-        kwargs['internal_weights'] = False
         super().__init__(irreps_in1, irreps_in2, out, instr, **kwargs)
